==> jc-1.4.0.tar.gz: soot/dava/toolkits/base/finders/LabeledBlockFinder.h <==
// public class soot.dava.toolkits.base.finders.LabeledBlockFinder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6b4064e4bbaa2d6c soot_dava_toolkits_base_finders_LabeledBlockFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_LabeledBlockFinder_H_
#define _JC_soot_dava_toolkits_base_finders_LabeledBlockFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$refs	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vmethods	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtable	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtype	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$build__5fConnectivity$31916aa5a1142594(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
extern void _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
extern void _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$find__5fLabeledBlocks$9c08c35369599575(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
extern void _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$perform__5fChildOrder$e722cbe059314f64(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method_info$build__5fConnectivity$31916aa5a1142594;
extern _jc_method _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method_info$find__5fLabeledBlocks$9c08c35369599575;
extern _jc_method _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method_info$perform__5fChildOrder$e722cbe059314f64;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$v$1e2fe04e1a676bac(_jc_env *);

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vmethods {
	struct _jc_object	*(*build__5fConnectivity$31916aa5a1142594)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
	void	(*find__5fLabeledBlocks$9c08c35369599575)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
	void	(*perform__5fChildOrder$e722cbe059314f64)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *);
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vmethods	soot_dava_toolkits_base_finders_LabeledBlockFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_refs {
	struct _jc_java_util_HashMap$object	*orderNumber;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$refs {
    _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_refs	soot_dava_toolkits_base_finders_LabeledBlockFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_nonrefs	soot_dava_toolkits_base_finders_LabeledBlockFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object {
	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtype _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_LabeledBlockFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_LabeledBlockFinder_H_ */

==> jc-1.4.6.tar.gz: soot/dava/toolkits/base/finders/LabeledBlockFinder.h <==
// public class soot.dava.toolkits.base.finders.LabeledBlockFinder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6b4064e4bbaa2d6c soot_dava_toolkits_base_finders_LabeledBlockFinder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_dava_toolkits_base_finders_LabeledBlockFinder_H_
#define _JC_soot_dava_toolkits_base_finders_LabeledBlockFinder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_java_util_List$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_dava_DavaBody$object;
struct _jc_soot_dava_internal_SET_SETNode$object;
struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object;
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object;
struct _jc_soot_util_IterableSet$object;

// Typedefs
typedef struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_refs	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_refs;
typedef struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_nonrefs	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$refs	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$refs;
typedef struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$nonrefs	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$nonrefs;
typedef struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object;

typedef const struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vmethods	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vmethods;
typedef const struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtable	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtable;
typedef const struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtype	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtype;

// Constructors
extern void _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$build__5fConnectivity$31916aa5a1142594(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$find$6aba89b6167e2073(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$find__5fLabeledBlocks$9c08c35369599575(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$perform__5fChildOrder$e722cbe059314f64(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method_info$build__5fConnectivity$31916aa5a1142594;
extern _jc_method _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method_info$find$6aba89b6167e2073;
extern _jc_method _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method_info$find__5fLabeledBlocks$9c08c35369599575;
extern _jc_method _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method_info$perform__5fChildOrder$e722cbe059314f64;

// Static methods
extern struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$method$v$1e2fe04e1a676bac(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vmethods {
	struct _jc_object	*(*build__5fConnectivity$31916aa5a1142594)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *, struct _jc_soot_util_IterableSet$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
	void	(*find$6aba89b6167e2073)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_DavaBody$object *, struct _jc_soot_dava_internal_asg_AugmentedStmtGraph$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
	void	(*find__5fLabeledBlocks$9c08c35369599575)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
	void	(*perform__5fChildOrder$e722cbe059314f64)(_jc_env *, struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object *, struct _jc_soot_dava_internal_SET_SETNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vmethods	soot_dava_toolkits_base_finders_LabeledBlockFinder;
};

// Vtype
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtype {
	_jc_type			type;
	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_refs {
	struct _jc_java_util_HashMap$object	*orderNumber;
};

// Reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$refs {
    _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_refs	soot_dava_toolkits_base_finders_LabeledBlockFinder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$sub_nonrefs	soot_dava_toolkits_base_finders_LabeledBlockFinder;
};

// Object instance structure
struct _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$object {
	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtype	*vtype;
	_jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$vtype _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_toolkits_base_finders_LabeledBlockFinder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_toolkits_base_finders_LabeledBlockFinder$class_object;

#endif	/* _JC_soot_dava_toolkits_base_finders_LabeledBlockFinder_H_ */
